#!/bin/sh

set -x

# Let's set a few variables
tag=$(date +%Y%m%d%H%M%S)
ver="0.0.1~$tag"
dir="/tmp/cloudfoundry-$ver"

# Create the build environment
mkdir -p "$dir"
cd "$dir"

# Grab the latest upstream source code
git clone git@github.com:vmware-ac/vcap.git
cd vcap && git submodule update --init && cd -
cd vcap && find ./ -name *.git* |xargs rm -rf && cd -
mv vcap cloudfoundry-server-$ver

# Create the orig tarball
tar -zcf cloudfoundry-server_$ver.orig.tar.gz cloudfoundry-server-$ver

# Grab the packaging sources
bzr branch lp:~cloudfoundry/+junk/server-packaging
mv -f server-packaging/debian cloudfoundry-server-$ver
cd cloudfoundry-server-$ver

# Fixup the package versioning
dch -i "Nightly build"
dch -b -v $ver-0ubuntu1~ppa1 "Nightly build"
# Would like to use dch -r here, but dch refuses to allow "oneiric"
sed -i "s/$ver-0ubuntu1~ppa1).*$/$ver-0ubuntu1~ppa1) oneiric; urgency=low/" debian/changelog

# Build the source package
debuild -S

# Upload
dput ppa:cloudfoundry/daily ../*changes

# Cleanup
cd
rm -rf "$dir"
